@@ -83,6 +83,9 @@ class Input(object):
         self.fulfillment = fulfillment
         self.fulfills = fulfills
         self.owners_before = owners_before
+        
+        self.app_key = None
+        self.app_id = None
 
     def __eq__(self, other):
         # TODO: If `other !== Fulfillment` return `False`
@@ -221,7 +224,7 @@ class TransactionLink(object):
             `txid`.
     """
 
-    def __init__(self, txid=None, output=None):
+    def __init__(self, txid=None, output=None, spent=False):
         """Create an instance of a :class:`~.TransactionLink`.
 
             Note:
@@ -238,6 +241,8 @@ class TransactionLink(object):
         """
         self.txid = txid
         self.output = output
+        self.spent = spent
+
 
     def __bool__(self):
         return self.txid is not None and self.output is not None
@@ -260,7 +265,7 @@ class TransactionLink(object):
                 :class:`~bigchaindb.common.transaction.TransactionLink`
         """
         try:
-            return cls(link['transaction_id'], link['output_index'])
+            return cls(link['transaction_id'], link['output_index'], None)
         except TypeError:
             return cls()
 
@@ -276,6 +281,7 @@ class TransactionLink(object):
             return {
                 'transaction_id': self.txid,
                 'output_index': self.output,
+                'spent': self.spent
             }
 
     def to_uri(self, path=''):
