@@ -284,7 +284,14 @@ class BigchainDB(object):
             pointing to another transaction's condition
         """
         outputs = self.fastquery.get_outputs_by_public_key(owner)
+
         if spent is None:
+            spents = self.fastquery.filter_unspent_outputs(outputs)
+            if spents:
+                for output in outputs:
+                    filtered = filter(lambda x: x.txid == output.txid, spents)
+                    output.spent = any(list(filter(lambda x: x.txid == output.txid, spents)))
+
             return outputs
         elif spent is True:
             return self.fastquery.filter_unspent_outputs(outputs)
